# Indico Platform Management
[![Codeship Status for IndicoDataSolutions/indico-install](https://app.codeship.com/projects/52ec5580-2390-0138-f313-5e60cb46bbdf/status?branch=master)](https://app.codeship.com/projects/383042)

This repository contains tools to create and manage Indico K8S clusters. It is used by anyone who works with an Indico K8S Cluster.
Split off from indico-deployment, the docker container and CLI in this repository are kept consistent with original expectations

- [Introduction and Setup](https://github.com/IndicoDataSolutions/indico-deployment/wiki/Introduction-and-Setup)
- [Wiki](https://github.com/IndicoDataSolutions/indico-deployment/wiki)
- [Contributing](#contributing)


## Contributing
When making any changes to the CLI or tools, please appropriately document them in the wiki and include the updated pages as part of your PR.

## Version Updates
Update the version number in setup.py as part of PR, after tested thoroughly
Add any changes to the CHANGELOG
